@@ -1,11 +1,9 @@
 package Pcore::DBD::DDL::Pg;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::DBD::DDL];
 
-no Pcore;
-
 1;
 __END__
 =pod
